<?php

class Brivium_CreditsIntegration_UserUpgrades_ControllerPublic_Account extends XFCP_Brivium_CreditsIntegration_UserUpgrades_ControllerPublic_Account
{
	public function actionUpgradePurchaseCredit()
	{
		$userUpgradeId = $this->_input->filterSingle('user_upgrade_id', XenForo_Input::UINT);
		$subscribe = $this->_input->filterSingle('subscribe', XenForo_Input::UINT);
		$upgrade = $this->_getUserUpgradeOrError($userUpgradeId);
		$upgrade = $this->getModelFromCache('XenForo_Model_UserUpgrade')->prepareUserUpgrade($upgrade);
		$upgrade['brciuu_record_subscribe'] = $subscribe;
		$visitor = XenForo_Visitor::getInstance()->toArray();
		
		list($event, $currency) = $this->getCreditHelper('Credit')->assertEventAndCurrencyValidAndViewable('BRCIPurchaseUserUpgrade',$upgrade['brciuu_currency_id']);
		
		$remain = $visitor[$currency['column']] - $upgrade['cost_amount'];
		if ( $remain < 0) {
			return $this->responseError(new XenForo_Phrase('BRC_not_enough_amount',array('amount' => XenForo_Application::get('brcCurrencies')->currencyFormat($upgrade['cost_amount'],false,$upgrade['brciuu_currency_id']))));
		}
		
		if ($this->isConfirmedPost())
		{
			$creditModel = $this->_getCreditModel();
			$dataCredit = array(
				'amount' 			=>	-$upgrade['cost_amount'],
				'user'				=>	$visitor,
				'currency_id'		=>	$upgrade['brciuu_currency_id'],
				'content_id' 		=>	$upgrade['user_upgrade_id'],
				'content_type'		=>	'user_upgrade',
				'message'			=>	'['.$upgrade['title'].']',
			);
			if(!$creditModel->updateUserCredit('BRCIPurchaseUserUpgrade',$visitor['user_id'],$dataCredit,$error)){
				return $this->responseError($error);
			}
			$this->getModelFromCache('XenForo_Model_UserUpgrade')->upgradeUser($visitor['user_id'], $upgrade, true);
			
			return $this->responseRedirect(
				XenForo_ControllerResponse_Redirect::SUCCESS,
				XenForo_Link::buildPublicLink('account/upgrades')
			);
		}else{
			
			$viewParams = array(
				'upgrade' => $upgrade,
				'remain' => $remain,
			);
			return $this->responseView('XenForo_ViewPublic_Account_UpgradePurchaseCredit', 'BRCIUU_account_upgrade_purchase_credit_confirm', $viewParams);
		}
	}
	
	public function actionSubscribeUpgradeCredit()
	{
		$userUpgradeId = $this->_input->filterSingle('user_upgrade_id', XenForo_Input::UINT);
		$subscribe = $this->_input->filterSingle('subscribe', XenForo_Input::UINT);
		$upgrade = $this->_getUserUpgradeOrError($userUpgradeId);
		$upgradeModel = $this->getModelFromCache('XenForo_Model_UserUpgrade');
		$upgrade = $upgradeModel->prepareUserUpgrade($upgrade);
		$visitor = XenForo_Visitor::getInstance()->toArray();
		$active = $upgradeModel->getActiveUserUpgradeRecord($visitor['user_id'], $upgrade['user_upgrade_id']);
		if(!$active){
			return $this->responseError(new XenForo_Phrase('BRCIUU_you_not_purchase_upgrade'));
		}
		
		if(!$upgrade['length_unit'] || !$upgrade['recurring'] || !$upgrade['brciuu_using_credit'] || !$upgrade['brciuu_currency_id'] || !$active['brciuu_record_credit']){
			return $this->responseNoPermission();
		}
		if ($this->isConfirmedPost())
		{
			$this->getModelFromCache('XenForo_Model_UserUpgrade')->subscribeUpgrade($visitor['user_id'], $upgrade, $subscribe);
			
			return $this->responseRedirect(
				XenForo_ControllerResponse_Redirect::SUCCESS,
				XenForo_Link::buildPublicLink('account/upgrades')
			);
		}else{
			
			$viewParams = array(
				'upgrade' => $upgrade,
				'active' => $active,
			);
			return $this->responseView('XenForo_ViewPublic_Account_UpgradePurchaseCredit', 'BRCIUU_upgrade_subscribe_confirm', $viewParams);
		}
	}
	
	protected function _getUserUpgradeOrError($id)
	{
		$upgradeModel = $this->getModelFromCache('XenForo_Model_UserUpgrade');

		return $this->getRecordOrError(
			$id, $upgradeModel, 'getUserUpgradeById',
			'requested_user_upgrade_not_found'
		);
	}
	public function getCreditHelper($class)
	{
		if (strpos($class, '_') === false)
		{
			$class = 'Brivium_Credits_ControllerHelper_' . $class;
		}

		$class = XenForo_Application::resolveDynamicClass($class);

		return new $class($this);
	}
	/**
	 * Gets the action model.
	 *
	 * @return Brivium_Credits_Model_Credit
	 */
	protected function _getCreditModel()
	{
		return $this->getModelFromCache('Brivium_Credits_Model_Credit');
	}
	
}
