<?php

/**
 * Model for user upgrades.
 *
 * @package XenForo_UserUpgrade
 */
class Brivium_CreditsIntegration_UserUpgrades_Model_UserUpgrade extends XFCP_Brivium_CreditsIntegration_UserUpgrades_Model_UserUpgrade
{
	public function getUserUpgradesByIds(array $ids)
	{
		if (!$userIds)
		{
			return array();
		}
		return $this->fetchAllKeyed('
				SELECT *
				FROM xf_user_upgrade
				WHERE user_id IN (' . $this->_getDb()->quote($ids) . ')
		', 'user_id');
	}
	
	public function prepareUserUpgrade(array $upgrade)
	{
		$upgrade = parent::prepareUserUpgrade($upgrade);
		if(!empty($upgrade['brciuu_using_credit']) && !empty($upgrade['brciuu_currency_id'])){
			$cost = XenForo_Application::get('brcCurrencies')->currencyFormat($upgrade['cost_amount'],false,$upgrade['brciuu_currency_id']);

			if ($upgrade['length_unit'])
			{
				if ($upgrade['length_amount'] > 1)
				{
					if ($upgrade['recurring'])
					{
						$upgrade['costPhrase'] = new XenForo_Phrase("x_per_y_$upgrade[length_unit]s", array(
							'cost' => $cost,
							'length' => $upgrade['length_amount']
						));
					}
					else
					{
						$upgrade['costPhrase'] = new XenForo_Phrase("x_for_y_$upgrade[length_unit]s", array(
							'cost' => $cost,
							'length' => $upgrade['length_amount']
						));
					}
				}
				else
				{
					if ($upgrade['recurring'])
					{
						$upgrade['costPhrase'] = new XenForo_Phrase("x_per_$upgrade[length_unit]", array(
							'cost' => $cost
						));
					}
					else
					{
						$upgrade['costPhrase'] = new XenForo_Phrase("x_for_one_$upgrade[length_unit]", array(
							'cost' => $cost
						));
					}
				}
			}
			else
			{
				$upgrade['costPhrase'] = $cost;
			}
		}

		return $upgrade;
	}
	
	public function subscribeUpgrade($userId, array $upgrade, $subscribe)
	{
		$db = $this->_getDb();
		$active = $this->getActiveUserUpgradeRecord($userId, $upgrade['user_upgrade_id']);
		if($active && !empty($upgrade['brciuu_using_credit']) && !empty($upgrade['brciuu_currency_id'])){
			$db->update('xf_user_upgrade_active',
				array(
					'brciuu_record_subscribe' => $subscribe,
				),
				'user_id = ' . $db->quote($userId) . ' AND user_upgrade_id = ' . $db->quote($upgrade['user_upgrade_id'])
			);
		}
	}
	
	public function upgradeUser($userId, array $upgrade, $allowInsertUnpurchasable = false, $endDate = null)
	{
		$upgradeRecordId = parent::upgradeUser($userId, $upgrade, $allowInsertUnpurchasable, $endDate);
		$db = $this->_getDb();

		if(isset($upgrade['brciuu_record_subscribe']) && $upgradeRecordId && !empty($upgrade['brciuu_using_credit']) && !empty($upgrade['brciuu_currency_id'])){
			$db->update('xf_user_upgrade_active',
				array(
					'brciuu_record_credit' => 1,
					'brciuu_record_subscribe' => $upgrade['brciuu_record_subscribe'],
				),
				'user_upgrade_record_id = ' . $db->quote($upgradeRecordId) . ' AND user_upgrade_id = ' . $db->quote($upgrade['user_upgrade_id'])
			);
		}
	}
	
	
	
	public function downgradeUserUpgrades(array $upgrades)
	{
		if(!empty($GLOBALS['BRCIUU_ControllerAdmin_UserUpgrade_actionDowngrade'])){
			return parent::downgradeUserUpgrades($upgrades);
		}
		if (!$upgrades)
		{
			return;
		}
		$upgradeRenew = array();
		
		$creditModel = $this->_getCreditModel();
		
		$creditModel->setIsBulk(true);
		$creditModel->setIsWaitSubmit(true);
		foreach ($upgrades AS $key=>$upgradeRecord)
		{
			if(!empty($upgradeRecord['brciuu_record_credit']) && !empty($upgradeRecord['brciuu_record_subscribe']) && ($upgrade = $this->getUserUpgradeById($upgradeRecord['user_upgrade_id']))){
				$dataCredit = array(
					'amount' 			=>	-$upgrade['cost_amount'],
					'currency_id'		=>	$upgrade['brciuu_currency_id'],
					'content_id' 		=>	$upgrade['user_upgrade_id'],
					'content_type'		=>	'user_upgrade',
					'message'			=>	'['.$upgrade['title'].']',
				);
				if($creditModel->updateUserCredit('BRCIPurchaseUserUpgrade',$upgradeRecord['user_id'],$dataCredit,$error)){
					$this->upgradeUser($upgradeRecord['user_id'], $upgrade, true);
					unset($upgrades[$key]);
				}
			}
		}
		$creditModel->commitUpdate();
		
		
		return parent::downgradeUserUpgrades($upgrades);
		
	}
	
	protected function _getCreditModel()
	{
		return $this->getModelFromCache('Brivium_Credits_Model_Credit');
	}
	
}